@@ -44,7 +44,7 @@ make_syn<-function(index,
 	return(out)
 }
 
-# Function used in generate,placebos
+# Function used in generate.placebos
 # 
 syn_plac <- function(i, 
 										 dataprep.out, 
@@ -52,7 +52,9 @@ syn_plac <- function(i,
 										 tr, 
 										 names.and.numbers) {
 	cases <- as.numeric(dataprep.out$tag$controls.identifier)
-	X0 <- dataprep.out$X0[, -i]
+	if(length(dataprep.out$tag$predictors)+length(dataprep.out$tag$special.predictors) > 1) {
+		X0 <- dataprep.out$X0[, -i] } else {
+			X0 <- t(matrix(dataprep.out$X0[, -i, drop = F]))}
 	X1 <- matrix(dataprep.out$X0[, i, drop = F])
 	Z0 <- dataprep.out$Z0[, -i]
 	Z1 <- matrix(dataprep.out$Z0[, i, drop = F])
